/* Copyright 2017 - 2025 R. Thomas
 * Copyright 2017 - 2025 Quarkslab
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef LIEF_PE_UTILS_LIBRARY_TABLE_H
#define LIEF_PE_UTILS_LIBRARY_TABLE_H

#include "kernel32_dll_lookup.hpp"
#include "ntdll_dll_lookup.hpp"
#include "advapi32_dll_lookup.hpp"
#include "user32_dll_lookup.hpp"
#include "comctl32_dll_lookup.hpp"
#include "ws2_32_dll_lookup.hpp"
#include "shcore_dll_lookup.hpp"
#include "oleaut32_dll_lookup.hpp"
#include "msvcrt_dll_lookup.hpp"
#include "ole32_dll_lookup.hpp"
#include "mfc42u_dll_lookup.hpp"
#include "shlwapi_dll_lookup.hpp"
#include "gdi32_dll_lookup.hpp"
#include "shell32_dll_lookup.hpp"

#include "msvcp110_dll_lookup.hpp"
#include "msvcp120_dll_lookup.hpp"

#include "msvcr100_dll_lookup.hpp"
#include "msvcr110_dll_lookup.hpp"
#include "msvcr120_dll_lookup.hpp"


#endif
